@@ -457,6 +457,115 @@ class RedisRoot:
         else:
             raise Exception(f'{django_model} is not registered')
 
+    def django_fields_to_redis_fields(self, django_model, save_related_models, exclude_fields):
+        redis_fields = {}
+        for django_field in django_model._meta.get_fields():
+            django_field_name = django_field.name
+            allowed = True
+            if exclude_fields:
+                allowed = (django_field.name not in exclude_fields)
+            if allowed:
+                if django_field.name in ['id', 'pk']:
+                    django_field_name = 'django_id'
+                    redis_field = RedisNumber(null=True)
+                else:
+                    redis_field = self.django_field_to_redis_field(django_field, save_related_models, exclude_fields)
+                if redis_field:
+                    redis_fields[django_field_name] = redis_field
+        return redis_fields
+
+    def create_redis_model_from_redis_fields(self, django_model, redis_fields, register=True):
+        new_redis_model = type(django_model.__name__, (RedisModel,), redis_fields)
+        self.registered_models([new_redis_model])
+        return new_redis_model
+
+    def django_field_to_redis_field(self, django_field, save_related_models, exclude_fields):
+
+        field_mapping = {
+            django_models.BooleanField: RedisBool,
+            django_models.DecimalField: RedisDecimal,
+            django_models.PositiveSmallIntegerField: RedisNumber,
+            django_models.BigAutoField: RedisNumber,
+            django_models.BigIntegerField: RedisNumber,
+            django_models.DateField: RedisDate,
+            django_models.DateTimeField: RedisDateTime,
+            django_models.EmailField: RedisString,
+            django_models.IntegerField: RedisNumber,
+            django_models.GenericIPAddressField: RedisString,
+            django_models.JSONField: RedisJson,
+            django_models.PositiveBigIntegerField: RedisNumber,
+            django_models.PositiveIntegerField: RedisNumber,
+            django_models.SmallAutoField: RedisNumber,
+            django_models.SmallIntegerField: RedisNumber,
+            django_models.TextField: RedisString,
+            django_models.URLField: RedisString,
+            django_models.UUIDField: RedisString,
+            django_models.ForeignKey: RedisForeignKey,
+            django_models.ManyToManyField: RedisManyToMany
+        }
+
+        if django_field.__class__.__name__.endswith('Rel'):
+            redis_field = None
+        elif django_field.__class__ in field_mapping.keys():
+            redis_field = field_mapping[django_field.__class__]
+        else:
+            redis_field = RedisString
+
+        if redis_field:
+            redis_field_class = type(
+                django_field.__class__.__name__,
+                (redis_field,),
+                {}
+            )
+
+            redis_field_params = self.django_field_params_to_redis_field_params(django_field,
+                                                                           save_related_models, exclude_fields)
+            redis_field = redis_field_class(**redis_field_params)
+        return redis_field
+
+    def django_field_params_to_redis_field_params(self, django_field, save_related_models, exclude_fields):
+        allowed_params = ['default', 'choices', 'remote_field']
+        allowed_redis_params = {}
+        django_field_params = django_field.__dict__.copy()
+        for django_field_param_name in django_field_params.keys():
+            redis_field_param_name = django_field_param_name
+            if django_field_param_name in allowed_params:
+                value = getattr(django_field, django_field_param_name)
+                if value in [django_models.NOT_PROVIDED, django_models.Empty, django_models.BLANK_CHOICE_DASH, None]:
+                    value = None
+                if django_field_param_name == 'choices':
+                    real_value = {}
+                    if value is not None:
+                        for choice in value:
+                            real_value[choice[0]] = choice[1]
+                    else:
+                        real_value = None
+                    value = real_value
+                    allowed_redis_params[redis_field_param_name] = value
+                elif django_field_param_name == 'remote_field':
+                    redis_field_param_name = 'model'
+                    if value is not None:
+                        value = value.model
+                        if value is not None:
+                            value = self.get_or_create_redis_model_from_django_model(value)
+                            if value is not None:
+                                allowed_redis_params[redis_field_param_name] = value
+                                allowed_redis_params['save_related_models'] = save_related_models
+                else:
+                    allowed_redis_params[redis_field_param_name] = value
+        return allowed_redis_params
+
+    def update_redis_model_from_redis_fields(self, django_model, existing_redis_model, redis_fields):
+        new_redis_model = self.create_redis_model_from_redis_fields(django_model, redis_fields, False)
+        new_registered_models = []
+        for redis_model in self.registered_models:
+            if redis_model == existing_redis_model:
+                new_registered_models.append(new_redis_model)
+            else:
+                new_registered_models.append(redis_model)
+        self.registered_models = new_registered_models
+        return new_redis_model
+
     def get_or_create_redis_model_from_django_model(self, django_model):
         if self.performance['enabled']:
             if 'get_or_create_redis_model_from_django_model' not in self.performance.keys():
@@ -465,137 +574,24 @@ class RedisRoot:
                     'time': 0
                 }
             self.performance['get_or_create_redis_model_from_django_model']['requests'] += 1
-
-
-        started_in = datetime.datetime.now()
-
-        def django_fields_to_redis_fields(django_model, redis_root, save_related_models, exclude_fields):
-            redis_fields = {}
-            for django_field in django_model._meta.get_fields():
-                django_field_name = django_field.name
-                allowed = True
-                if exclude_fields:
-                    allowed = (django_field.name not in exclude_fields)
-                if allowed:
-                    if django_field.name in ['id', 'pk']:
-                        django_field_name = 'django_id'
-                        redis_field = RedisNumber(null=True)
-                    else:
-                        redis_field = django_field_to_redis_field(django_field, redis_root, save_related_models,
-                                                                  exclude_fields)
-                    if redis_field:
-                        redis_fields[django_field_name] = redis_field
-            return redis_fields
-
-        def create_redis_model_from_redis_fields(django_model, redis_fields, redis_root):
-            new_redis_model = type(django_model.__name__, (RedisModel,), redis_fields)
-            redis_root.register_models([new_redis_model])
-            return new_redis_model
-
-        def django_field_to_redis_field(django_field, redis_root, save_related_models, exclude_fields):
-
-            field_mapping = {
-                django_models.BooleanField: RedisBool,
-                django_models.DecimalField: RedisDecimal,
-                django_models.PositiveSmallIntegerField: RedisNumber,
-                django_models.BigAutoField: RedisNumber,
-                django_models.BigIntegerField: RedisNumber,
-                django_models.DateField: RedisDate,
-                django_models.DateTimeField: RedisDateTime,
-                django_models.EmailField: RedisString,
-                django_models.IntegerField: RedisNumber,
-                django_models.GenericIPAddressField: RedisString,
-                django_models.JSONField: RedisJson,
-                django_models.PositiveBigIntegerField: RedisNumber,
-                django_models.PositiveIntegerField: RedisNumber,
-                django_models.SmallAutoField: RedisNumber,
-                django_models.SmallIntegerField: RedisNumber,
-                django_models.TextField: RedisString,
-                django_models.URLField: RedisString,
-                django_models.UUIDField: RedisString,
-                django_models.ForeignKey: RedisForeignKey,
-                django_models.ManyToManyField: RedisManyToMany
-            }
-
-            if django_field.__class__.__name__.endswith('Rel'):
-                redis_field = None
-            elif django_field.__class__ in field_mapping.keys():
-                redis_field = field_mapping[django_field.__class__]
-            else:
-                redis_field = RedisString
-
-            if redis_field:
-                redis_field_class = type(
-                    django_field.__class__.__name__,
-                    (redis_field,),
-                    {}
-                )
-
-                redis_field_params = django_field_params_to_redis_field_params(django_field, redis_root,
-                                                                               save_related_models, exclude_fields)
-                redis_field = redis_field_class(**redis_field_params)
-            return redis_field
-
-        def django_field_params_to_redis_field_params(django_field, redis_root, save_related_models, exclude_fields):
-            allowed_params = ['default', 'choices', 'remote_field']
-            allowed_redis_params = {}
-            django_field_params = django_field.__dict__.copy()
-            for django_field_param_name in django_field_params.keys():
-                redis_field_param_name = django_field_param_name
-                if django_field_param_name in allowed_params:
-                    value = getattr(django_field, django_field_param_name)
-                    if value in [django_models.NOT_PROVIDED, django_models.Empty, django_models.BLANK_CHOICE_DASH, None]:
-                        value = None
-                    if django_field_param_name == 'choices':
-                        real_value = {}
-                        if value is not None:
-                            for choice in value:
-                                real_value[choice[0]] = choice[1]
-                        else:
-                            real_value = None
-                        value = real_value
-                        allowed_redis_params[redis_field_param_name] = value
-                    elif django_field_param_name == 'remote_field':
-                        redis_field_param_name = 'model'
-                        if value is not None:
-                            value = value.model
-                            if value is not None:
-                                value = redis_root.get_or_create_redis_model_from_django_model(value)
-                                if value is not None:
-                                    allowed_redis_params[redis_field_param_name] = value
-                                    allowed_redis_params['save_related_models'] = save_related_models
-                    else:
-                        allowed_redis_params[redis_field_param_name] = value
-            return allowed_redis_params
-
-        def update_redis_model_from_redis_fields(django_model, existing_redis_model, redis_fields, redis_root):
-            new_redis_model = create_redis_model_from_redis_fields(django_model, redis_fields, redis_root)
-            new_registered_models = []
-            for redis_model in redis_root.registered_models:
-                if redis_model == existing_redis_model:
-                    new_registered_models.append(new_redis_model)
-                else:
-                    new_registered_models.append(redis_model)
-            redis_root.registered_models = new_registered_models
-            return new_redis_model
+            started_in = datetime.datetime.now()
 
         cache_conf = self.get_cache_conf(django_model)
         save_related_models = cache_conf['save_related_models']
         exclude_fields = cache_conf['exclude_fields']
-
-
-        redis_fields = django_fields_to_redis_fields(django_model, self, save_related_models, exclude_fields)
+        redis_fields = self.django_fields_to_redis_fields(django_model, save_related_models, exclude_fields)
         registered_models_names = [model.__name__ for model in self.registered_models]
         if django_model.__name__ in registered_models_names:
             existing_redis_model_index = registered_models_names.index(django_model.__name__)
             existing_redis_model = self.registered_models[existing_redis_model_index]
-            new_redis_model = update_redis_model_from_redis_fields(django_model, existing_redis_model, redis_fields,
-                                                                   self)
+            new_redis_model = self.update_redis_model_from_redis_fields(django_model, existing_redis_model, redis_fields)
         else:
-            new_redis_model = create_redis_model_from_redis_fields(django_model, redis_fields, self)
+            new_redis_model = self.create_redis_model_from_redis_fields(django_model, redis_fields)
+        print(len(self.registered_models))
         ended_in = datetime.datetime.now()
         if self.performance['enabled']:
             self.performance['get_or_create_redis_model_from_django_model']['time'] += (ended_in-started_in).total_seconds()
+
         return new_redis_model
 
     def check_cache(self):
